Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.cpp	(revision 73579)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.cpp	(revision 73580)
@@ -69,5 +69,5 @@
     , m_pAccountPropertyTable(0)
 {
-    /* Init Cloud User-profile Manager: */
+    /* Init Cloud Provider Manager: */
     CVirtualBox comVBox = vboxGlobal().virtualBox();
     m_comCloudProviderManager = comVBox.CreateCloudProviderManager();
@@ -118,36 +118,35 @@
 
     /* Acquire provider ID list: */
-//  QVector<KCloudProviderId> providerIds = m_comCloudProviderManager.GetSupportedProviders();
     QVector<QString> providerIds = m_comCloudProviderManager.GetSupportedProviders();
     /* Make sure at least one provider is supported: */
     AssertReturnVoid(!providerIds.isEmpty());
 
-    /* Iterate through provider types: */
-//  foreach (KCloudProviderId enmType, providerIds)
-//  {
-//      /* Acquire Cloud User-profile List: */
-//      CCloudUserProfiles comProfiles = m_comCloudProviderManager.GetProfilesByProvider(enmType);
-//      /* Skip if we have nothing to populate (file missing?): */
-//      if (comProfiles.isNull())
-//          continue;
-//
-//      /* Iterate through profile names: */
-//      foreach (const QString &strProfileName, comProfiles.GetStoredProfilesNames())
-//      {
-//          m_pAccountComboBox->addItem(QString());
-//          m_pAccountComboBox->setItemData(m_pAccountComboBox->count() - 1, (int)enmType, ProviderID);
-//          m_pAccountComboBox->setItemData(m_pAccountComboBox->count() - 1, strProfileName, ProfileName);
-//      }
-//  }
-//
-//  /* Set default: */
-//  if (m_pAccountComboBox->count() != 0)
-//      setProvider(KCloudProviderId_OCI);
+    /* Iterate through provider IDs: */
+    foreach (const QString &strProviderId, providerIds)
+    {
+        /* Acquire Cloud Provider: */
+        const CCloudProvider comProvider = m_comCloudProviderManager.GetProfilesByProvider(strProviderId);
+        /* Skip if we have nothing to populate (file missing?): */
+        if (comProvider.isNull())
+            continue;
+
+        /* Iterate through profile names: */
+        foreach (const QString &strProfileName, comProvider.GetStoredProfilesNames())
+        {
+            m_pAccountComboBox->addItem(QString());
+            m_pAccountComboBox->setItemData(m_pAccountComboBox->count() - 1, strProviderId, ProviderID);
+            m_pAccountComboBox->setItemData(m_pAccountComboBox->count() - 1, strProfileName, ProfileName);
+        }
+    }
+
+    /* Set default: */
+    if (m_pAccountComboBox->count() != 0)
+        setProviderById("OCI");
 }
 
 void UIWizardExportAppPage2::populateAccountProperties()
 {
-    /* Acquire Cloud User-profile List: */
-    m_comCloudProvider = m_comCloudProviderManager.GetProfilesByProvider(provider());
+    /* Acquire Cloud Provider: */
+    m_comCloudProvider = m_comCloudProviderManager.GetProfilesByProvider(providerId());
     /* Return if we have nothing to populate (file missing?): */
     if (m_comCloudProvider.isNull())
@@ -160,5 +159,5 @@
     QVector<QString> keys;
     QVector<QString> values;
-    values = m_comCloudProvider.GetProfileProperties(profile(), keys);
+    values = m_comCloudProvider.GetProfileProperties(profileName(), keys);
 
     /* Configure table: */
@@ -369,5 +368,5 @@
 {
     const int iIndex = m_pFormatComboBox->findData(strFormat);
-    AssertMsg(iIndex != -1, ("Field not found!"));
+    AssertMsg(iIndex != -1, ("Data not found!"));
     m_pFormatComboBox->setCurrentIndex(iIndex);
 }
@@ -392,5 +391,5 @@
 {
     const int iIndex = m_pMACComboBox->findData((int)enmMACAddressPolicy);
-    AssertMsg(iIndex != -1, ("Field not found!"));
+    AssertMsg(iIndex != -1, ("Data not found!"));
     m_pMACComboBox->setCurrentIndex(iIndex);
 }
@@ -416,25 +415,18 @@
 }
 
-void UIWizardExportAppPage2::setProvider(KCloudProviderId enmProvider)
-{
-    const int iIndex = m_pAccountComboBox->findData((int)enmProvider, ProviderID);
-    AssertMsg(iIndex != -1, ("Field not found!"));
+void UIWizardExportAppPage2::setProviderById(const QString &strId)
+{
+    const int iIndex = m_pAccountComboBox->findData(strId, ProviderID);
+    AssertMsg(iIndex != -1, ("Data not found!"));
     m_pAccountComboBox->setCurrentIndex(iIndex);
 }
 
-//KCloudProviderId UIWizardExportAppPage2::provider() const
-//{
-//  const int iIndex = m_pAccountComboBox->currentIndex();
-//  return (KCloudProviderId)m_pAccountComboBox->itemData(iIndex, ProviderID).toInt();
-//}
-
-QString UIWizardExportAppPage2::provider() const
-{
-    return "OCI";
-//const int iIndex = m_pAccountComboBox->currentIndex();
-//return (KCloudProviderId)m_pAccountComboBox->itemData(iIndex, ProviderID).toInt();
-}
-
-QString UIWizardExportAppPage2::profile() const
+QString UIWizardExportAppPage2::providerId() const
+{
+    const int iIndex = m_pAccountComboBox->currentIndex();
+    return m_pAccountComboBox->itemData(iIndex, ProviderID).toString();
+}
+
+QString UIWizardExportAppPage2::profileName() const
 {
     const int iIndex = m_pAccountComboBox->currentIndex();
@@ -442,5 +434,5 @@
 }
 
-CCloudProvider UIWizardExportAppPage2::profiles() const
+CCloudProvider UIWizardExportAppPage2::provider() const
 {
     return m_comCloudProvider;
@@ -702,6 +694,6 @@
     registerField("manifestSelected", this, "manifestSelected");
     registerField("includeISOsSelected", this, "includeISOsSelected");
-    registerField("profiles", this, "profiles");
-    registerField("profile", this, "profile");
+    registerField("profileName", this, "profileName");
+    registerField("provider", this, "provider");
 }
 
@@ -794,5 +786,5 @@
     for (int i = 0; i < m_pAccountComboBox->count(); ++i)
     {
-        if (m_pAccountComboBox->itemData(i, ProviderID).toInt() == KCloudProviderId_OCI)
+        if (m_pAccountComboBox->itemData(i, ProviderID).toString() == "OCI")
         {
             m_pAccountComboBox->setItemText(i, UIWizardExportApp::tr("Oracle Cloud Infrastructure: %1", "provider: profile")
@@ -802,5 +794,5 @@
         {
             m_pAccountComboBox->setItemText(i, UIWizardExportApp::tr("%1: %2", "provider: profile")
-                .arg(gpConverter->toInternalInteger((KCloudProviderId)m_pAccountComboBox->itemData(i, ProviderID).toInt()))
+                .arg(m_pAccountComboBox->itemData(i, ProviderID).toString())
                 .arg(m_pAccountComboBox->itemData(i, ProfileName).toString()));
         }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic3.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic3.cpp	(revision 73579)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic3.cpp	(revision 73580)
@@ -57,11 +57,11 @@
     m_listCloudClientParameters.clear();
 
-    /* Acquire Cloud User-profiles: */
-    CCloudProvider comCloudProvider = fieldImp("profiles").value<CCloudProvider>();
+    /* Acquire Cloud Provider: */
+    CCloudProvider comCloudProvider = fieldImp("provider").value<CCloudProvider>();
     AssertMsgReturnVoid(comCloudProvider.isNotNull(),
                         ("Cloud provider object is undefined!"));
 
     /* Create Cloud Client: */
-    CCloudClient comCloudClient = comCloudProvider.CreateCloudClient(fieldImp("profile").toString());
+    CCloudClient comCloudClient = comCloudProvider.CreateCloudClient(fieldImp("profileName").toString());
     AssertMsgReturnVoid(comCloudProvider.isOk() && comCloudClient.isNotNull(),
                         ("Can't create Cloud Client object!"));
@@ -72,5 +72,5 @@
     /* Create JSON document on the basis of it, make sure it isn't empty: */
     const QJsonDocument document = QJsonDocument::fromJson(strJSON.toUtf8());
-    AssertMsgReturnVoid(!document.isEmpty(), ("Document is empty!"));
+    AssertMsgReturnVoid(!document.isEmpty(), ("JSON document is empty!"));
 
     /* Parse JSON document: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.cpp	(revision 73579)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.cpp	(revision 73580)
@@ -349,6 +349,6 @@
     registerField("manifestSelected", this, "manifestSelected");
     registerField("includeISOsSelected", this, "includeISOsSelected");
-    registerField("profiles", this, "profiles");
-    registerField("profile", this, "profile");
+    registerField("profileName", this, "profileName");
+    registerField("provider", this, "provider");
     registerField("applianceWidget", this, "applianceWidget");
 }
@@ -432,14 +432,14 @@
     for (int i = 0; i < m_pAccountComboBox->count(); ++i)
     {
-        if (m_pAccountComboBox->itemData(i, Qt::UserRole + 1).toInt() == KCloudProviderId_OCI)
+        if (m_pAccountComboBox->itemData(i, ProviderID).toString() == "OCI")
         {
             m_pAccountComboBox->setItemText(i, UIWizardExportApp::tr("Oracle Cloud Infrastructure: %1", "provider: profile")
-                .arg(m_pAccountComboBox->itemData(i, Qt::UserRole + 2).toString()));
+                .arg(m_pAccountComboBox->itemData(i, ProfileName).toString()));
         }
         else
         {
             m_pAccountComboBox->setItemText(i, UIWizardExportApp::tr("%1: %2", "provider: profile")
-                .arg(gpConverter->toInternalInteger((KCloudProviderId)m_pAccountComboBox->itemData(i, Qt::UserRole + 1).toInt()))
-                .arg(m_pAccountComboBox->itemData(i, Qt::UserRole + 2).toString()));
+                .arg(m_pAccountComboBox->itemData(i, ProviderID).toString())
+                .arg(m_pAccountComboBox->itemData(i, ProfileName).toString()));
         }
     }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.h	(revision 73579)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageExpert.h	(revision 73580)
@@ -41,6 +41,6 @@
     Q_PROPERTY(bool manifestSelected READ isManifestSelected WRITE setManifestSelected);
     Q_PROPERTY(bool includeISOsSelected READ isIncludeISOsSelected WRITE setIncludeISOsSelected);
-    Q_PROPERTY(CCloudProvider profiles READ profiles);
-    Q_PROPERTY(QString profile READ profile);
+    Q_PROPERTY(CCloudProvider provider READ provider);
+    Q_PROPERTY(QString profileName READ profileName);
     Q_PROPERTY(ExportAppliancePointer applianceWidget READ applianceWidget);
 

Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.h	(revision 73579)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.h	(revision 73580)
@@ -125,18 +125,17 @@
     void setIncludeISOsSelected(bool fChecked);
 
-    /** Defines @a strProvider. */
-    void setProvider(KCloudProviderId enmProvider);
-    /** Returns provider. */
-//  KCloudProviderId provider() const;
-    QString provider() const;
-    /** Returns profile. */
-    QString profile() const;
-    /** Returns Cloud User-profile object. */
-    CCloudProvider profiles() const;
-
-    /** Holds the Cloud User-profile Manager reference. */
+    /** Defines provider by @a strId. */
+    void setProviderById(const QString &strId);
+    /** Returns provider ID. */
+    QString providerId() const;
+    /** Returns profile name. */
+    QString profileName() const;
+    /** Returns Cloud Provider object. */
+    CCloudProvider provider() const;
+
+    /** Holds the Cloud Provider Manager reference. */
     CCloudProviderManager  m_comCloudProviderManager;
-    /** Holds the Cloud User-profile object reference. */
-    CCloudProvider     m_comCloudProvider;
+    /** Holds the Cloud Provider object reference. */
+    CCloudProvider         m_comCloudProvider;
 
     /** Holds the default appliance name. */
@@ -198,6 +197,6 @@
     Q_PROPERTY(bool manifestSelected READ isManifestSelected WRITE setManifestSelected);
     Q_PROPERTY(bool includeISOsSelected READ isIncludeISOsSelected WRITE setIncludeISOsSelected);
-    Q_PROPERTY(CCloudProvider profiles READ profiles);
-    Q_PROPERTY(QString profile READ profile);
+    Q_PROPERTY(CCloudProvider provider READ provider);
+    Q_PROPERTY(QString profileName READ profileName);
 
 public: